Trait style::shared_lock::DeepCloneWithLock
[−]
[src]
pub trait DeepCloneWithLock: Sized {
fn deep_clone_with_lock(
&self,
lock: &SharedRwLock,
guard: &SharedRwLockReadGuard,
params: &DeepCloneParams
) -> Self;
}A trait to do a deep clone of a given CSS type. Gets a lock and a read guard, in order to be able to read and clone nested structures.
Required Methods
fn deep_clone_with_lock(
&self,
lock: &SharedRwLock,
guard: &SharedRwLockReadGuard,
params: &DeepCloneParams
) -> Self
&self,
lock: &SharedRwLock,
guard: &SharedRwLockReadGuard,
params: &DeepCloneParams
) -> Self
Deep clones this object.
Implementors
impl DeepCloneWithLock for DocumentRuleimpl DeepCloneWithLock for ImportSheetimpl DeepCloneWithLock for ImportRuleimpl DeepCloneWithLock for KeyframesRuleimpl DeepCloneWithLock for Keyframeimpl DeepCloneWithLock for MediaRuleimpl DeepCloneWithLock for PageRuleimpl DeepCloneWithLock for CssRulesimpl DeepCloneWithLock for StyleRuleimpl DeepCloneWithLock for StylesheetContentsimpl DeepCloneWithLock for SupportsRuleimpl DeepCloneWithLock for CssRule